@@ -1,12 +1,12 @@
 #! /usr/bin/env python
 ## vim: fileencoding=utf-8
 #
-# Copyright (c) 2007 Adeodato Simó (dato@net.com.org.es)
+# Copyright (c) 2007-2009 Adeodato Simó (dato@net.com.org.es)
 # Licensed under the terms of the MIT license.
 
 import time
 
-import qt
+from PyQt4 import QtCore
 try:
     import lastfm.client
     _has_lastfm_client = True
@@ -19,7 +19,7 @@ from minirok import engine, util
 
 ##
 
-class LastfmSubmitter(qt.QObject, util.HasGUIConfig):
+class LastfmSubmitter(QtCore.QObject):
     """An object that takes care of submiting played tracks to Last.fm.
 
     It relies on the Playlist.new_track signal. Upon receiving it, it starts a
@@ -27,11 +27,12 @@ class LastfmSubmitter(qt.QObject, util.HasGUIConfig):
     timer is paused accordingly.
     """
     def __init__(self):
-        qt.QObject.__init__(self)
-        util.HasGUIConfig.__init__(self)
+        QtCore.QObject.__init__(self)
+        util.CallbackRegistry.register_apply_prefs(self.apply_preferences)
 
         self.data = None
-        self.timer = util.QTimerWithPause(self, 'lastfm timer')
+        self.timer = util.QTimerWithPause(self)
+        self.timer.setSingleShot(True)
 
         if _has_lastfm_client:
             self.lastfm_client = lastfm.client.Client('minirok')
@@ -44,19 +45,18 @@ class LastfmSubmitter(qt.QObject, util.HasGUIConfig):
         if minirok.Globals.preferences.enable_lastfm:
             func = self.connect
         else:
-            # Grrr, self.disconnect() without arguments does not work
             func = self.disconnect
 
-        func(minirok.Globals.playlist, qt.PYSIGNAL('new_track'),
+        func(minirok.Globals.playlist, QtCore.SIGNAL('new_track'),
                 self.slot_new_track)
 
-        minirok.Globals.engine.connect(
-                qt.PYSIGNAL('status_changed'), self.slot_engine_status_changed)
+        func(minirok.Globals.engine, QtCore.SIGNAL('status_changed'),
+                self.slot_engine_status_changed)
 
-        func(self.timer, qt.SIGNAL('timeout()'), self.slot_submit)
+        func(self.timer, QtCore.SIGNAL('timeout()'), self.slot_submit)
 
     def slot_new_track(self):
-        all_tags = minirok.Globals.playlist.currently_playing
+        all_tags = minirok.Globals.playlist.get_current_tags()
         self.data = dict((k.lower(), v) for k, v in all_tags.items()
                                         if k in ['Title', 'Artist', 'Length'])
 
