@@ -7,23 +7,20 @@ set -e
 
 ##
 
-if ! kde-config 2>/dev/null; then
-    echo >&2 "ERROR: could not find kde-config."
+if ! kde4-config 2>/dev/null; then
+    echo >&2 "ERROR: could not find kde4-config."
     exit 1
 fi
 
 ##
 
-PREFIX=`kde-config --prefix`
-BIN=`kde-config --expandvars --install exe`
-APPS=`kde-config --expandvars --install data`
-ICONS=`kde-config --expandvars --install icon`
-CONFIG=`kde-config --expandvars --install config`
-DESKTOP=`kde-config --expandvars --install xdgdata-apps`
+PREFIX=`kde4-config --prefix`
+BIN=`kde4-config --install exe`
+APPS=`kde4-config --install data`
+ICONS=`kde4-config --install icon`
+DESKTOP=`kde4-config --install xdgdata-apps`
+SERVICE_MENUS=`kde4-config --install services`/ServiceMenus
 MINIROK="$APPS/minirok"
-KHOTKEYS="$APPS/khotkeys"
-KCONF_UPDATE="$APPS/kconf_update"
-KONQUEROR_SERVICE_MENU="$APPS/konqueror/servicemenus"
 
 ##
 
@@ -87,11 +84,10 @@ case "$1" in
 	install_package
 	install_manpage
 	install_icons images/icons "$ICONS"
-	install_file config/minirokrc "$CONFIG"
+	install_icons images/icons/private "$MINIROK/icons"
+	install_file config/minirokui.rc "$MINIROK"
 	install_file config/minirok.desktop "$DESKTOP"
-	install_file config/minirok.khotkeys "$KHOTKEYS"
-	install_file config/khotkeys_minirok.upd "$KCONF_UPDATE"
-	install_file config/minirok_append.desktop "$KONQUEROR_SERVICE_MENU"
+	install_file config/minirok_append.desktop "$SERVICE_MENUS"
 	install_symlink "$PREFIX/share/minirok/minirok.py" "$BIN/minirok"
 	;;
 
